@@ -162,7 +162,8 @@ This function uses `geiser-guile-init-file' if it exists."
              (while (not (zerop (geiser-syntax--nesting-level)))
                (backward-up-list)))
            (if (or (re-search-backward geiser-guile--module-re nil t)
-                   (looking-at geiser-guile--library-re))
+                   (looking-at geiser-guile--library-re)
+                   (re-search-forward geiser-guile--module-re nil t))
                (geiser-guile--get-module (match-string-no-properties 1))
              :f)))
         ((listp module) module)
