@@ -107,6 +107,19 @@ expression, if any."
   :type 'integer
   :group 'geiser-repl)
 
+(geiser-custom--defcustom geiser-repl-startup-time 10000
+  "Time, in milliseconds, to wait for Racket to startup.
+If you have a slow system, try to increase this time."
+  :type 'integer
+  :group 'geiser-repl)
+
+(geiser-custom--defface repl-input
+  'comint-highlight-input geiser-repl "evaluated input highlighting")
+
+(geiser-custom--defface repl-prompt
+  'comint-highlight-prompt geiser-repl "REPL prompt")
+
+
 
 ;;; Implementation-dependent parameters
 
@@ -302,7 +315,7 @@ module command as a string")
                      (error-message-string err)
                      "\n")
              (error "Couldn't start Geiser")))
-    (geiser-repl--wait-for-prompt 10000)))
+    (geiser-repl--wait-for-prompt geiser-repl-startup-time)))
 
 (defun geiser-repl--wait-for-prompt (timeout)
   (let ((p (point)) (seen) (buffer (current-buffer)))
@@ -503,7 +516,7 @@ there's no symbol at point). Otherwise, go to next error in the REPL
 buffer."
   (interactive "p")
   (if (>= (point) (geiser-repl--last-prompt-end))
-      (completion-at-point)
+      (or (completion-at-point) (lisp-indent-line))
     (compilation-next-error n)))
 
 (defun geiser-repl--previous-error (n)
@@ -511,10 +524,14 @@ buffer."
   (interactive "p")
   (compilation-next-error (- n)))
 
+
 (define-derived-mode geiser-repl-mode comint-mode "REPL"
   "Major mode for interacting with an inferior scheme repl process.
 \\{geiser-repl-mode-map}"
   (scheme-mode-variables)
+  (set (make-local-variable 'face-remapping-alist)
+       '((comint-highlight-prompt geiser-font-lock-repl-prompt)
+         (comint-highlight-input geiser-font-lock-repl-input)))
   (set (make-local-variable 'mode-line-process) nil)
   (set (make-local-variable 'comint-use-prompt-regexp) t)
   (set (make-local-variable 'comint-prompt-read-only)
@@ -581,7 +598,9 @@ buffer."
   "Start a new Geiser REPL."
   (interactive
    (list (geiser-repl--get-impl "Start Geiser for scheme implementation: ")))
-  (geiser-repl--start-repl impl nil))
+  (let ((buffer (current-buffer)))
+    (geiser-repl--start-repl impl nil)
+    (geiser-repl--maybe-remember-scm-buffer buffer)))
 
 (defalias 'geiser 'run-geiser)
 
@@ -589,12 +608,20 @@ buffer."
   "Start a new Geiser REPL connected to a remote Scheme process."
   (interactive
    (list (geiser-repl--get-impl "Connect to Scheme implementation: ")))
-  (geiser-repl--start-repl impl
-                           (geiser-repl--read-address host port)))
+  (let ((buffer (current-buffer)))
+    (geiser-repl--start-repl impl
+                             (geiser-repl--read-address host port))
+    (geiser-repl--maybe-remember-scm-buffer buffer)))
 
 (make-variable-buffer-local
  (defvar geiser-repl--last-scm-buffer nil))
 
+(defun geiser-repl--maybe-remember-scm-buffer (buffer)
+  (when (and buffer
+             (eq 'scheme-mode (with-current-buffer buffer major-mode))
+             (eq major-mode 'geiser-repl-mode))
+    (setq geiser-repl--last-scm-buffer buffer)))
+
 (defun switch-to-geiser (&optional ask impl buffer)
   "Switch to running Geiser REPL.
 With prefix argument, ask for which one if more than one is running.
@@ -618,8 +645,7 @@ If no REPL is running, execute `run-geiser' to start a fresh one."
           (repl (geiser-repl--switch-to-buffer repl))
           ((geiser-repl--remote-p) (geiser-connect impl))
           (t (run-geiser impl)))
-    (when (and buffer (eq major-mode 'geiser-repl-mode))
-      (setq geiser-repl--last-scm-buffer buffer))))
+    (geiser-repl--maybe-remember-scm-buffer buffer)))
 
 (defun switch-to-geiser-module (&optional module buffer)
   "Switch to running Geiser REPL and try to enter a given module."
